dofile("data/scripts/lib/mod_settings.lua") -- see this file for documentation on some of the features.

function mod_setting_bool_custom( mod_id, gui, in_main_menu, im_id, setting )
	local value = ModSettingGetNextValue( mod_setting_get_id(mod_id,setting) )
	local text = setting.ui_name .. " - " .. GameTextGet( value and "$option_on" or "$option_off" )

	if GuiButton( gui, im_id, mod_setting_group_x_offset, 0, text ) then
		ModSettingSetNextValue( mod_setting_get_id(mod_id,setting), not value, false )
	end

	mod_setting_tooltip( mod_id, gui, in_main_menu, setting )
end

function mod_setting_change_callback( mod_id, gui, in_main_menu, setting, old_value, new_value  )
	print( tostring(new_value) )
end

local mod_id = "random_starting_wand" -- This should match the name of your mod's folder.
mod_settings_version = 1 -- This is a magic global that can be used to migrate settings to new mod versions. call mod_settings_get_version() before mod_settings_update() to get the old value. 
mod_settings = 
{
	{
		category_id = "random_starting_wand_config_stuff",
		ui_name = "STUFF",
		ui_description = "Spawn with more or less stuff!",
		settings = {
			{
				id = "starting_spell_count",
				ui_name = "Starting Spells",
				ui_description = "How many spells to start with?",
				value_default = "0",
				text_max_length = 2,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "spell_tier",
				ui_name = "Spell Tier",
				ui_description = "What tier for the spells?",
				value_default = "0",
				text_max_length = 1,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "random_perk_count",
				ui_name = "Starting Perks",
				ui_description = "How many perks to start with?",
				value_default = "0",
				text_max_length = 2,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "potion_type",
				ui_name = "Potion Pool",
				ui_description = "What kind of potion should be given?",
				value_default = "potion.xml",
				values = { {"potion.xml","Random"}, {"potion_starting.xml","Starter"}, {"potion_agressive.xml","Agressive"}, {"potion_random_material.xml","Any Liquid/powder"}, {"potion_empty.xml","Empty"} },
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "potion_amount",
				ui_name = "Potion Amount",
				ui_description = "How many potions to give?",
				value_default = "1",
				text_max_length = 1,
				allowed_characters = "01234",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
		},
	},
	{
		category_id = "random_starting_wand_config",
		ui_name = "CONFIG",
		ui_description = "Misc options related to stuff.",
		settings = {
			{
				id = "pickup",
				ui_name = "Pickup Items",
				ui_description = "If disabled, all starting equipment will be dropped, instead of forceibly placed in your inventory.",
				value_default = true,
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "time_seeded",
				ui_name = "Time Seeded",
				ui_description = "Change weather starting items are dependant on world seed or system time.\nPerks are always dependant on seed.\nAs a side effect items spawn in slightly off center with Pickup Items disabled",
				value_default = false,
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "wand_tinker",
				ui_name = "Starter Wand Tinkering",
				ui_description = "Grants a small wand tinker area where you spawn for 2.5 minutes.",
				value_default = false,
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "give_random_wands",
				ui_name = "Clear Inventory",
				ui_description = "Weather or not your inventory is cleared before adding random equipment.\nRecomended to turn on, since this being on means your regular starting equipment will be there alongside the new stuff.",
				value_default = true,
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			
		},
	},
	{
		category_id = "random_starting_wand_first",
		ui_name = "FIRST WAND",
		ui_description = "What will your first wand be?",
		foldable = true,
		_folded = true, -- this field will be automatically added to each gategory table to store the current folding state
		settings = {
			{
				id = "wand_type_1",
				ui_name = "Wand Type",
				ui_description = "What kind of wand should be given?",
				value_default = "tiered",
				values = { {"tiered","Tiered"}, {"handgun","Blue Starting Wand"}, {"bomb","Bomb Starting Wand"}, {"off","None"} },
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "wand_tier_1",
				ui_name = "Wand Tier",
				ui_description = "ONLY APPLICABLE IF WAND TYPE IS TIERED\nWhat tier for the wand?",
				value_default = "1",
				text_max_length = 2,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
		},
	},
	{
		category_id = "random_starting_wand_2",
		ui_name = "SECOND WAND",
		ui_description = "What will your second wand be?",
		foldable = true,
		_folded = true, -- this field will be automatically added to each gategory table to store the current folding state
		settings = {
			{
				id = "wand_type_2",
				ui_name = "Wand Type",
				ui_description = "What kind of wand should be given?",
				value_default = "tiered",
				values = { {"tiered","Tiered"}, {"handgun","Blue Starting Wand"}, {"bomb","Bomb Starting Wand"}, {"off","None"} },
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "wand_tier_2",
				ui_name = "Wand Tier",
				ui_description = "ONLY APPLICABLE IF WAND TYPE IS TIERED\nWhat tier for the wand?",
				value_default = "1",
				text_max_length = 2,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
		},
	},
	{
		category_id = "random_starting_wand_3",
		ui_name = "THIRD WAND",
		ui_description = "What will your third wand be?",
		foldable = true,
		_folded = true, -- this field will be automatically added to each gategory table to store the current folding state
		settings = {
			{
				id = "wand_type_3",
				ui_name = "Wand Type",
				ui_description = "What kind of wand should be given?",
				value_default = "off",
				values = { {"tiered","Tiered"}, {"handgun","Blue Starting Wand"}, {"bomb","Bomb Starting Wand"}, {"off","None"} },
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "wand_tier_3",
				ui_name = "Wand Tier",
				ui_description = "ONLY APPLICABLE IF WAND TYPE IS TIERED\nWhat tier for the wand?",
				value_default = "1",
				text_max_length = 2,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
		},
	},
	{
		category_id = "random_starting_wand_4",
		ui_name = "FOURTH WAND",
		ui_description = "What will your fourth wand be?",
		foldable = true,
		_folded = true, -- this field will be automatically added to each gategory table to store the current folding state
		settings = {
			{
				id = "wand_type_4",
				ui_name = "Wand Type",
				ui_description = "What kind of wand should be given?",
				value_default = "off",
				values = { {"tiered","Tiered"}, {"handgun","Blue Starting Wand"}, {"bomb","Bomb Starting Wand"}, {"off","None"} },
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
			{
				id = "wand_tier_4",
				ui_name = "Wand Tier",
				ui_description = "ONLY APPLICABLE IF WAND TYPE IS TIERED\nWhat tier for the wand?",
				value_default = "1",
				text_max_length = 2,
				allowed_characters = "0123456789",
				scope = MOD_SETTING_SCOPE_NEW_GAME,
			},
		},
	},
}
function ModSettingsUpdate( init_scope )
	local old_version = mod_settings_get_version( mod_id ) -- This can be used to migrate some settings between mod versions.
	mod_settings_update( mod_id, mod_settings, init_scope )
end
function ModSettingsGuiCount()
	return mod_settings_gui_count( mod_id, mod_settings )
end
function ModSettingsGui( gui, in_main_menu )
	mod_settings_gui( mod_id, mod_settings, gui, in_main_menu )
end
